#include "config.h"

#include <gtk/gtk.h>

#include "boilerplate-application.h"
#include "boilerplate-window.h"

typedef struct
{
    GSettings *settings;
} BoilerplateWindowPrivate;

G_DEFINE_TYPE_WITH_PRIVATE(BoilerplateWindow, boilerplate_window, GTK_TYPE_APPLICATION_WINDOW)

static void
boilerplate_window_class_init (BoilerplateWindowClass *class)
{
    gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (class),
                                                 "/io/github/julianrichen/boilerplate/ui/window.ui");

    /*
    gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (class), BoilerplateWindow, stack);
    */
}

static void
boilerplate_window_init (BoilerplateWindow *self)
{
    BoilerplateApplication *application = BOILERPLATE_APPLICATION (g_application_get_default ());
    BoilerplateWindowPrivate *priv = boilerplate_window_get_instance_private(self);
    GtkBuilder *builder;

    // Center window on screen
    //TODO: Fix & Load last location from gsettings
    gtk_window_set_position (GTK_WINDOW (self), GTK_WIN_POS_CENTER);

    // Init window.ui template
    gtk_widget_init_template (GTK_WIDGET (self));

    // Add toolbar (headerbar contents) if needed
    builder = gtk_builder_new_from_resource ("/io/github/julianrichen/boilerplate/ui/toolbar.ui");
    self->toolbar = GTK_WIDGET (gtk_builder_get_object (builder, "toolbar"));

    //TODO: Polish toolbar methid
    // Basiclly we have the contents of the headerbar in a ui file called toolbar.ui
    // Inside that file is a GtkContainer/GtkGrid (yet to be decided) that is
    // loaded into either:
    // a) The GTK toolbar in window.ui
    // b) The contents of the window.ui; headerbar in window.ui is disabled;
    //    menubar is enabled

    if (application->disable_csd) {
        // Add "headerbar", a.k.a toolbar, to body of window
        gtk_container_add (GTK_CONTAINER (self), self->toolbar);
    } else {
        // Else make the toolbar the headerbar
        gtk_window_set_titlebar (GTK_WINDOW (self), self->toolbar);
    }


    // Clean-up builder
    g_object_unref (builder);
}

BoilerplateWindow *
boilerplate_window_new (BoilerplateApplication *application)
{
    //TODO: Load application self or pass as a paramter?

    return g_object_new (BOILERPLATE_TYPE_WINDOW,
                         "application", application,
                         "title", "Boilerplate for C & GTK3",
                         //TODO: Investigate
                         "show-menubar", FALSE,
                         NULL);
}
